import { PutObjectCommand } from '@aws-sdk/client-s3';
import { createGenericFileFromJson, lamports } from '@metaplex-foundation/umi';

class AwsUploader {
  constructor(client, bucketName) {
    this.client = client;
    this.bucketName = bucketName;
  }
  async uploadOne(file) {
    const command = new PutObjectCommand({
      Bucket: this.bucketName,
      Key: file.uniqueName,
      Body: file.buffer,
      ContentType: file.contentType || undefined
    });
    await this.client.send(command);
    return this.getUrl(file.uniqueName);
  }
  async upload(files) {
    return Promise.all(files.map(file => this.uploadOne(file)));
  }
  async uploadJson(json) {
    const file = createGenericFileFromJson(json);
    const uris = await this.upload([file]);
    return uris[0];
  }
  async getUploadPrice() {
    return lamports(0);
  }
  async getUrl(key) {
    const region = await this.client.config.region();
    const encodedKey = encodeURIComponent(key);
    return `https://s3.${region}.amazonaws.com/${this.bucketName}/${encodedKey}`;
  }
}

export { AwsUploader };
//# sourceMappingURL=AwsUploader.mjs.map
